<?php
if (!defined('ABSPATH')) die('-1');

if (!class_exists("ASP_Media_Service_License")) {
	class ASP_Media_Service_License {
		private static $_instance;
		private $data;

		private function __construct() {
			$this->data = get_option('_asp_media_service_data', array(
				'license' => false,
				'active' => false,
				'stats' => array()
			));
		}

		function active() {
			return $this->data['license'] !== false && $this->data['active'];
		}

		function valid() {
			if (
				(int)$this->data['stats']['max_files'] >= (int)$this->data['stats']['max_files_usage']
			) {
				/**
				 * The "stats" are updated ONLY during indexing. If the max_file threshold was met during a recent
				 * index, then max_files < max_files_usage forever, and this function would return "false" all the time.
				 * If the last check was performed over 5 minutes ago, the report "true" even if the files
				 * threshold was met, so a request will be made to the media server to verify that.
				 */
				if ( ( time() - (int)$this->data['last_check'] ) > 300 ) {
					return true;
				} else {
					return false;
				}
			} else {
				return true;
			}
		}

		function deactivate() {
			$this->data['active'] = false;
			update_option('_asp_media_service_data', $this->data);
		}

		function get() {
			return $this->data['license'] !== false ? $this->data['license'] : '';
		}

		function set($license, $active, $stats) {
			$this->data = array(
				'license' => $license,
				'active' => $active,
				'last_check' => time(),
				'stats' => $stats
			);
			update_option('_asp_media_service_data', $this->data);
		}

		function setStats( $stats = false ) {
			if ( $stats !== false && $this->data['license'] !== false ) {
				$this->data['stats'] = $stats;
				update_option('_asp_media_service_data', array(
					'license' => $this->data['license'],
					'active' => $this->data['active'],
					'last_check' => time(),
					'stats' => $stats
				));
			}
		}

		// ------------------------------------------------------------
		//   ---------------- SINGLETON SPECIFIC --------------------
		// ------------------------------------------------------------
		public static function getInstance() {
			if ( ! ( self::$_instance instanceof self ) ) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}
	}
}